@@ -9,174 +9,33 @@ class ProductService:
     def __init__(self, client):
         self.__client = client
 
-    def get_shop_categories(self, shop_id):
+    def upload_image(self, image):
         """
-        查询店铺商品分类
-        :param shopId:店铺Id
+        上传图片，返回图片的hash值
+        :param image:文件内容base64编码值
         """
-        return self.__client.call("eleme.product.category.getShopCategories", {"shopId": shop_id})
+        return self.__client.call("eleme.file.uploadImage", {"image": image})
 
-    def get_shop_categories_with_children(self, shop_id):
+    def upload_image_with_remote_url(self, url):
         """
-        查询店铺商品分类，包含二级分类
-        :param shopId:店铺Id
+        通过远程URL上传图片，返回图片的hash值
+        :param url:远程Url地址
         """
-        return self.__client.call("eleme.product.category.getShopCategoriesWithChildren", {"shopId": shop_id})
+        return self.__client.call("eleme.file.uploadImageWithRemoteUrl", {"url": url})
 
-    def get_category(self, category_id):
+    def get_uploaded_url(self, hash):
         """
-        查询商品分类详情
-        :param categoryId:商品分类Id
+        获取上传文件的访问URL，返回文件的Url地址
+        :param hash:图片hash值
         """
-        return self.__client.call("eleme.product.category.getCategory", {"categoryId": category_id})
+        return self.__client.call("eleme.file.getUploadedUrl", {"hash": hash})
 
-    def get_category_with_children(self, category_id):
+    def get_image_url(self, hash):
         """
-        查询商品分类详情，包含二级分类
-        :param categoryId:商品分类Id
+        获取上传图片的url地址(新版)
+        :param hash:图片hash值
         """
-        return self.__client.call("eleme.product.category.getCategoryWithChildren", {"categoryId": category_id})
-
-    def create_category(self, shop_id, name, description):
-        """
-        添加商品分类
-        :param shopId:店铺Id
-        :param name:商品分类名称，长度需在50字以内
-        :param description:商品分类描述，长度需在50字以内
-        """
-        return self.__client.call("eleme.product.category.createCategory", {"shopId": shop_id, "name": name, "description": description})
-
-    def create_category_with_children(self, shop_id, name, parent_id, description):
-        """
-        添加商品分类，支持二级分类
-        :param shopId:店铺Id
-        :param name:商品分类名称，长度需在50字以内
-        :param parentId:父分类ID，如果没有可以填0
-        :param description:商品分类描述，长度需在50字以内
-        """
-        return self.__client.call("eleme.product.category.createCategoryWithChildren", {"shopId": shop_id, "name": name, "parentId": parent_id, "description": description})
-
-    def update_category(self, category_id, name, description):
-        """
-        更新商品分类
-        :param categoryId:商品分类Id
-        :param name:商品分类名称，长度需在50字以内
-        :param description:商品分类描述，长度需在50字以内
-        """
-        return self.__client.call("eleme.product.category.updateCategory", {"categoryId": category_id, "name": name, "description": description})
-
-    def update_category_with_children(self, category_id, name, parent_id, description):
-        """
-        更新商品分类，包含二级分类
-        :param categoryId:商品分类Id
-        :param name:商品分类名称，长度需在50字以内
-        :param parentId:父分类ID，如果没有可以填0
-        :param description:商品分类描述，长度需在50字以内
-        """
-        return self.__client.call("eleme.product.category.updateCategoryWithChildren", {"categoryId": category_id, "name": name, "parentId": parent_id, "description": description})
-
-    def remove_category(self, category_id):
-        """
-        删除商品分类
-        :param categoryId:商品分类Id
-        """
-        return self.__client.call("eleme.product.category.removeCategory", {"categoryId": category_id})
-
-    def invalid_category(self, category_id):
-        """
-        删除商品分类(新版)
-        :param categoryId:商品分类Id
-        """
-        return self.__client.call("eleme.product.category.invalidCategory", {"categoryId": category_id})
-
-    def set_category_positions(self, shop_id, category_ids):
-        """
-        设置分类排序
-        :param shopId:饿了么店铺Id
-        :param categoryIds:需要排序的分类Id
-        """
-        return self.__client.call("eleme.product.category.setCategoryPositions", {"shopId": shop_id, "categoryIds": category_ids})
-
-    def set_category_sequence(self, shop_id, category_ids):
-        """
-        设置分类排序(新版)
-        :param shopId:饿了么店铺Id
-        :param categoryIds:需要排序的全部一级分类Id
-        """
-        return self.__client.call("eleme.product.category.setCategorySequence", {"shopId": shop_id, "categoryIds": category_ids})
-
-    def set_category_positions_with_children(self, shop_id, category_with_children_ids):
-        """
-        设置二级分类排序
-        :param shopId:饿了么店铺Id
-        :param categoryWithChildrenIds:需要排序的父分类Id，及其下属的二级分类ID
-        """
-        return self.__client.call("eleme.product.category.setCategoryPositionsWithChildren", {"shopId": shop_id, "categoryWithChildrenIds": category_with_children_ids})
-
-    def get_back_category(self, shop_id):
-        """
-        查询商品后台类目
-        :param shopId:店铺Id
-        """
-        return self.__client.call("eleme.product.category.getBackCategory", {"shopId": shop_id})
-
-    def set_category_type(self, shop_id, category_id, category_type):
-        """
-        设置分类类型
-        :param shopId:店铺Id
-        :param categoryId:商品分类Id
-        :param categoryType:分类类型
-        """
-        return self.__client.call("eleme.product.category.setCategoryType", {"shopId": shop_id, "categoryId": category_id, "categoryType": category_type})
-
-    def set_day_parting_stick_time(self, shop_id, category_id, day_parting_stick):
-        """
-        设置分组分时段置顶
-        :param shopId:店铺Id
-        :param categoryId:商品分类Id
-        :param dayPartingStick:置顶时间设置
-        """
-        return self.__client.call("eleme.product.category.setDayPartingStickTime", {"shopId": shop_id, "categoryId": category_id, "dayPartingStick": day_parting_stick})
-
-    def remove_day_parting_stick_time(self, shop_id, category_id):
-        """
-        删除分组的分时置顶功能
-        :param shopId:店铺Id
-        :param categoryId:商品分类Id
-        """
-        return self.__client.call("eleme.product.category.removeDayPartingStickTime", {"shopId": shop_id, "categoryId": category_id})
-
-    def create_package(self, category_id, o_package):
-        """
-        添加套餐
-        :param categoryId:分类Id
-        :param oPackage:套餐属性
-        """
-        return self.__client.call("eleme.product.package.createPackage", {"categoryId": category_id, "oPackage": o_package})
-
-    def update_package_content(self, item_id, category_id, update):
-        """
-        修改套餐基本信息
-        :param itemId:新套餐id即OItem中的商品Id
-        :param categoryId:分类Id即OCategory中的分类Id
-        :param update:套餐基本信息
-        """
-        return self.__client.call("eleme.product.package.updatePackageContent", {"itemId": item_id, "categoryId": category_id, "update": update})
-
-    def update_package_relation(self, item_id, packages):
-        """
-        修改套餐和主料的关联关系
-        :param itemId:新套餐id即OItem中的商品Id
-        :param packages:套餐关系
-        """
-        return self.__client.call("eleme.product.package.updatePackageRelation", {"itemId": item_id, "packages": packages})
-
-    def remove_package(self, item_id):
-        """
-        删除套餐
-        :param itemId:套餐Id
-        """
-        return self.__client.call("eleme.product.package.removePackage", {"itemId": item_id})
+        return self.__client.call("eleme.file.getImageUrl", {"hash": hash})
 
     def get_items_by_category_id(self, category_id):
         """
@@ -420,31 +279,197 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.getRelatedItemIds", {"shopId": shop_id, "itemId": item_id})
 
-    def upload_image(self, image):
+    def create_multi_spec_item(self, category_id, properties):
         """
-        上传图片，返回图片的hash值
-        :param image:文件内容base64编码值
+        添加多规格商品
+        :param categoryId:商品分类Id
+        :param properties:商品属性
         """
-        return self.__client.call("eleme.file.uploadImage", {"image": image})
+        return self.__client.call("eleme.product.item.createMultiSpecItem", {"categoryId": category_id, "properties": properties})
 
-    def upload_image_with_remote_url(self, url):
+    def batch_create_multi_spec_item(self, category_id, items):
         """
-        通过远程URL上传图片，返回图片的hash值
-        :param url:远程Url地址
+        批量添加多规格商品
+        :param categoryId:商品分类Id
+        :param items:商品属性的列表
         """
-        return self.__client.call("eleme.file.uploadImageWithRemoteUrl", {"url": url})
+        return self.__client.call("eleme.product.item.batchCreateMultiSpecItem", {"categoryId": category_id, "items": items})
 
-    def get_uploaded_url(self, hash):
+    def update_multi_spec_item(self, item_id, category_id, properties):
         """
-        获取上传文件的访问URL，返回文件的Url地址
-        :param hash:图片hash值
+        更新多规格商品
+        :param itemId:商品Id
+        :param categoryId:商品分类Id
+        :param properties:商品属性
         """
-        return self.__client.call("eleme.file.getUploadedUrl", {"hash": hash})
+        return self.__client.call("eleme.product.item.updateMultiSpecItem", {"itemId": item_id, "categoryId": category_id, "properties": properties})
 
-    def get_image_url(self, hash):
+    def get_shop_categories(self, shop_id):
         """
-        获取上传图片的url地址(新版)
-        :param hash:图片hash值
+        查询店铺商品分类
+        :param shopId:店铺Id
         """
-        return self.__client.call("eleme.file.getImageUrl", {"hash": hash})
+        return self.__client.call("eleme.product.category.getShopCategories", {"shopId": shop_id})
+
+    def get_shop_categories_with_children(self, shop_id):
+        """
+        查询店铺商品分类，包含二级分类
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.product.category.getShopCategoriesWithChildren", {"shopId": shop_id})
+
+    def get_category(self, category_id):
+        """
+        查询商品分类详情
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.category.getCategory", {"categoryId": category_id})
+
+    def get_category_with_children(self, category_id):
+        """
+        查询商品分类详情，包含二级分类
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.category.getCategoryWithChildren", {"categoryId": category_id})
+
+    def create_category(self, shop_id, name, description):
+        """
+        添加商品分类
+        :param shopId:店铺Id
+        :param name:商品分类名称，长度需在50字以内
+        :param description:商品分类描述，长度需在50字以内
+        """
+        return self.__client.call("eleme.product.category.createCategory", {"shopId": shop_id, "name": name, "description": description})
+
+    def create_category_with_children(self, shop_id, name, parent_id, description):
+        """
+        添加商品分类，支持二级分类
+        :param shopId:店铺Id
+        :param name:商品分类名称，长度需在50字以内
+        :param parentId:父分类ID，如果没有可以填0
+        :param description:商品分类描述，长度需在50字以内
+        """
+        return self.__client.call("eleme.product.category.createCategoryWithChildren", {"shopId": shop_id, "name": name, "parentId": parent_id, "description": description})
+
+    def update_category(self, category_id, name, description):
+        """
+        更新商品分类
+        :param categoryId:商品分类Id
+        :param name:商品分类名称，长度需在50字以内
+        :param description:商品分类描述，长度需在50字以内
+        """
+        return self.__client.call("eleme.product.category.updateCategory", {"categoryId": category_id, "name": name, "description": description})
+
+    def update_category_with_children(self, category_id, name, parent_id, description):
+        """
+        更新商品分类，包含二级分类
+        :param categoryId:商品分类Id
+        :param name:商品分类名称，长度需在50字以内
+        :param parentId:父分类ID，如果没有可以填0
+        :param description:商品分类描述，长度需在50字以内
+        """
+        return self.__client.call("eleme.product.category.updateCategoryWithChildren", {"categoryId": category_id, "name": name, "parentId": parent_id, "description": description})
+
+    def remove_category(self, category_id):
+        """
+        删除商品分类
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.category.removeCategory", {"categoryId": category_id})
+
+    def invalid_category(self, category_id):
+        """
+        删除商品分类(新版)
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.category.invalidCategory", {"categoryId": category_id})
+
+    def set_category_positions(self, shop_id, category_ids):
+        """
+        设置分类排序
+        :param shopId:饿了么店铺Id
+        :param categoryIds:需要排序的分类Id
+        """
+        return self.__client.call("eleme.product.category.setCategoryPositions", {"shopId": shop_id, "categoryIds": category_ids})
+
+    def set_category_sequence(self, shop_id, category_ids):
+        """
+        设置分类排序(新版)
+        :param shopId:饿了么店铺Id
+        :param categoryIds:需要排序的全部一级分类Id
+        """
+        return self.__client.call("eleme.product.category.setCategorySequence", {"shopId": shop_id, "categoryIds": category_ids})
+
+    def set_category_positions_with_children(self, shop_id, category_with_children_ids):
+        """
+        设置二级分类排序
+        :param shopId:饿了么店铺Id
+        :param categoryWithChildrenIds:需要排序的父分类Id，及其下属的二级分类ID
+        """
+        return self.__client.call("eleme.product.category.setCategoryPositionsWithChildren", {"shopId": shop_id, "categoryWithChildrenIds": category_with_children_ids})
+
+    def get_back_category(self, shop_id):
+        """
+        查询商品后台类目
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.product.category.getBackCategory", {"shopId": shop_id})
+
+    def set_category_type(self, shop_id, category_id, category_type):
+        """
+        设置分类类型
+        :param shopId:店铺Id
+        :param categoryId:商品分类Id
+        :param categoryType:分类类型
+        """
+        return self.__client.call("eleme.product.category.setCategoryType", {"shopId": shop_id, "categoryId": category_id, "categoryType": category_type})
+
+    def set_day_parting_stick_time(self, shop_id, category_id, day_parting_stick):
+        """
+        设置分组分时段置顶
+        :param shopId:店铺Id
+        :param categoryId:商品分类Id
+        :param dayPartingStick:置顶时间设置
+        """
+        return self.__client.call("eleme.product.category.setDayPartingStickTime", {"shopId": shop_id, "categoryId": category_id, "dayPartingStick": day_parting_stick})
+
+    def remove_day_parting_stick_time(self, shop_id, category_id):
+        """
+        删除分组的分时置顶功能
+        :param shopId:店铺Id
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.category.removeDayPartingStickTime", {"shopId": shop_id, "categoryId": category_id})
+
+    def create_package(self, category_id, o_package):
+        """
+        添加套餐
+        :param categoryId:分类Id
+        :param oPackage:套餐属性
+        """
+        return self.__client.call("eleme.product.package.createPackage", {"categoryId": category_id, "oPackage": o_package})
+
+    def update_package_content(self, item_id, category_id, update):
+        """
+        修改套餐基本信息
+        :param itemId:新套餐id即OItem中的商品Id
+        :param categoryId:分类Id即OCategory中的分类Id
+        :param update:套餐基本信息
+        """
+        return self.__client.call("eleme.product.package.updatePackageContent", {"itemId": item_id, "categoryId": category_id, "update": update})
+
+    def update_package_relation(self, item_id, packages):
+        """
+        修改套餐和主料的关联关系
+        :param itemId:新套餐id即OItem中的商品Id
+        :param packages:套餐关系
+        """
+        return self.__client.call("eleme.product.package.updatePackageRelation", {"itemId": item_id, "packages": packages})
+
+    def remove_package(self, item_id):
+        """
+        删除套餐
+        :param itemId:套餐Id
+        """
+        return self.__client.call("eleme.product.package.removePackage", {"itemId": item_id})
 
